@@ -67,9 +67,8 @@ class ModelTorchAdapter(Model):
         batchCount = len(validationData)
         processList = tqdm(range(batchCount), disable=(not self.showProgress))
         processList.set_description("Validation")
-        batchGenerator = validationData.generator()
+        batchGenerator = iter(validationData)
 
-        iter(validationData)
         lastDimension = self.numClasses if self.oneHotDecoded else 1
         for batchIndex in processList:
             validationBatch = batchGenerator.__next__()
@@ -124,13 +123,12 @@ class ModelTorchAdapter(Model):
         return targets.float(), mask
 
     def train(self, dataset: TrainingSet):
-
         if ModelTorchAdapter.useTensorBoard:
             from torch.utils.tensorboard import SummaryWriter
 
             self.summarywriter = SummaryWriter()
 
-            for (f, title) in self.startFigures:
+            for f, title in self.startFigures:
                 self.summarywriter.add_figure(title, f)
         else:
             self.summarywriter = None
@@ -174,9 +172,8 @@ class ModelTorchAdapter(Model):
             batchesPerEpoch = len(dataset.trainingData)
             processList = tqdm(range(batchesPerEpoch), disable=(not self.showProgress))
             processList.set_description("EPOCH {}".format(i_epoch))
-            batchGenerator = dataset.trainingData.generator()
+            batchGenerator = iter(dataset.trainingData)
 
-            iter(dataset.trainingData)
             for batchIndex in processList:
                 trainBatch = next(batchGenerator)
                 batchFeats, targs = self.prepareDataAdapter(trainBatch)
@@ -315,7 +312,6 @@ class ModelTorchAdapter(Model):
         return self.logPath
 
     def build(self):
-
         torchSeed = 2
         torch.manual_seed(torchSeed)
 
