@@ -99,7 +99,7 @@ class MemmapRecordExporter(DataExporter):
         self.saveShape(dataId, *self.currentArrayShapes[dataId], tmp=True)
 
     def checkType(self, type):
-        return type == np.memmap or type == IterDataPipe or type == MapDataPipe
+        return type == np.memmap
 
     def getPath(self, dataId):
         return self.getOption("basePath") + dataId
